//
//  XSLTViewController.m
//  XSLTTest3
//
//  Created by Anthony Main on 15/11/2013.
//  Copyright (c) 2013 The Distance. All rights reserved.
//

#import "XSLTViewController.h"
#import <libxml/xmlmemory.h>
#import <libxml/debugXML.h>
#import <libxml/HTMLtree.h>
#import <libxml/xmlIO.h>
#import <libxml/xinclude.h>
#import <libxml/catalog.h>
#import "xslt.h"
#import "xsltInternals.h"
#import "transform.h"
#import "xsltutils.h"

@interface XSLTViewController ()

@property (weak) IBOutlet UIWebView *webView;

@end

@implementation XSLTViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
  
    NSString* filePath = [[NSBundle mainBundle] pathForResource: @"Test" ofType: @"xml"];
    NSData *xmlMem = [[NSData alloc] initWithContentsOfFile:filePath];
    
    NSString* styleSheetPath = [[NSBundle mainBundle] pathForResource: @"Test" ofType:@"xslt"];
    
    xmlDocPtr doc, res;
    xsltStylesheetPtr sty;
    
    // tells the libxml2 parser to substitute entities as it parses your file
    xmlSubstituteEntitiesDefault(1);
    // This tells libxml to load external entity subsets
    xmlLoadExtDtdDefaultValue = 1;
    
    // This following line is only really needed if you want to use XSLT params
    const char *params[3] = { [@"param1" cStringUsingEncoding:NSUTF8StringEncoding], [@"\"paramdata\"" cStringUsingEncoding:NSUTF8StringEncoding], NULL };
    
    sty = xsltParseStylesheetFile((const xmlChar *)[styleSheetPath cStringUsingEncoding: NSUTF8StringEncoding]);
    //doc = xmlParseFile([filePath cStringUsingEncoding: NSUTF8StringEncoding]);
    
    // This example loads the XML file from a memory location as a sample, you can reference file directly with different xmlParse methods
    doc = xmlParseMemory([xmlMem bytes], [xmlMem length]);
    
    // Pass in NULL instead of params if you don't need to use them
    res = xsltApplyStylesheet(sty, doc, params);
    
    xmlChar* xmlResultBuffer = nil;
    int length = 0;
    
    xsltSaveResultToString(&xmlResultBuffer, &length, res, sty);
    
    NSString* result = [NSString stringWithCString: (char *)xmlResultBuffer encoding: NSUTF8StringEncoding];
    
    NSLog(@"Result: %@", result);
    
    [self.webView loadHTMLString:result baseURL:nil];
    
    free(xmlResultBuffer);
    
    xsltFreeStylesheet(sty);
    xmlFreeDoc(res);
    xmlFreeDoc(doc);
    
    xsltCleanupGlobals();
    xmlCleanupParser();
    

}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
